
<!--
FrozenIsBool False
-->

#Itemizer

##Doc
----


> 
> An Itemizer...
> 
> 

----

<small>
View the Itemizer notebook on [NbViewer](http://nbviewer.ipython.org/url/shareyoursystem.ouvaton.org/Itemizer.ipynb)
</small>

